@@ -19,15 +19,28 @@
 #include <kapp.h>
 #include <klocale.h>
 #include <kiconloader.h>
+#include <qcursor.h>
+#include <qclipboard.h>
 #include <stdio.h>
+//#include <iostream.h>
 
 /*************************************************
  * create dockwidget with popup-menu             *
  *************************************************/
 dockwidget::dockwidget(QWidget *, const char * name) : KSystemTray(0, name)
 {
-  myview = 0;
-  mypop = 0;
+//  myview = 0;
+//  mypop = 0;
+
+
+  //create Popup-window
+  mypop = new KPopupFrame(this);
+  //we dont need decorations
+  mypop->setFrameStyle(QFrame::Box | QFrame::Plain);
+  mypop->setLineWidth(2); //black frame
+  // TextView
+  myview = new QTextView(mypop);
+  myview->setFrameStyle(QFrame::NoFrame);
 
   popup_menu = new KPopupMenu(this);
   popup_menu->setTitle("KSteak");
@@ -55,7 +68,15 @@ dockwidget::~dockwidget()
 void dockwidget::mousePressEvent(QMouseEvent* e)
 {
   if (e->button() == RightButton) popup_menu->exec(QCursor::pos());
-  if (e->button() == LeftButton) getTranslation(QString());
+  if (e->button() == LeftButton)
+  {
+  	if (myview->hasSelectedText())
+  		getTranslation( myview->selectedText() );
+	else
+		getTranslation( kapp->clipboard()->text() );
+
+	//getTranslation("");
+  }
 }
 
 /*************************************************
@@ -72,8 +93,9 @@ void dockwidget::getTranslation(const QString & szWord)
 {
   int x = QCursor::pos().x();
   int y = QCursor::pos().y();
-  
-  if (myview) delete myview; 
+
+/*
+  if (myview) delete myview;
   if (mypop) delete mypop;
 
   //create Popup-window
@@ -84,7 +106,7 @@ void dockwidget::getTranslation(const QString & szWord)
   // TextView
   myview = new QTextView(mypop);
   myview->setFrameStyle(QFrame::NoFrame);
-  
+*/
   emit translate( szWord );
 
   int w = myview->width();
