@@ -16,7 +16,13 @@
  ***************************************************************************/
 
 #include "ksteak.h"
+#include "options.h"
+
 #include <qtooltip.h>
+#include <qstring.h>
+#include <qcolor.h>
+#include <qclipboard.h>
+
 #include <kiconloader.h>
 #include <kmessagebox.h>
 #include <kaccel.h>
@@ -24,9 +30,6 @@
 #include <kmenubar.h>
 #include <kconfig.h>
 #include <klocale.h>
-#include <qstring.h>
-#include <qcolor.h>
-#include "options.h"
 #include <kaction.h>
 #include <kstdaction.h>
 #include <kedittoolbar.h>
@@ -38,13 +41,12 @@
 KSteak::KSteak()
 	: DCOPObject("KSteakIface"), SteakDock(0)
 {
-    new KAction( i18n("Start &Search"), "search", CTRL+Key_S, this,SLOT(slotStartSearch()),actionCollection(),"search" );
     new KAction( i18n("&Dock to Panel"), CTRL+Key_D, this, SLOT(slotDock()), actionCollection(), "dock" );
     KStdAction::quit( this, SLOT(slotQuit()), actionCollection() );
 
     actions.English = new KToggleAction( i18n("&English"), "flag-en", 0, this, SLOT(slotToggleEnglish()), actionCollection(), "english" );
     actions.German = new KToggleAction( i18n("&German"), "flag-de", 0, this, SLOT(slotToggleGerman()), actionCollection(), "german" );
-    actions.Context = new KToggleAction( i18n("Show &Context"), "contents2", 0, this, SLOT(slotToggleShowContext()), actionCollection(), "context" );
+    actions.Context = new KToggleAction( i18n("Show &Context"), "context", 0, this, SLOT(slotToggleShowContext()), actionCollection(), "context" );
     actions.Case = new KToggleAction( i18n("Case &sensitive"), "case", 0, this, SLOT(slotToggleCaseSensitive()), actionCollection(), "case_sens" );
     actions.AND = new KToggleAction( i18n("&AND"), "and", 0, this, SLOT(slotToggleAND()), actionCollection(), "and" );
     actions.OR = new KToggleAction( i18n("&OR"), "or", 0, this, SLOT(slotToggleOR()), actionCollection(), "or" );
@@ -58,28 +60,31 @@ KSteak::KSteak()
     actions.inputLine->setEditable(true);
 
     connect(actions.inputLine, SIGNAL(activated(const QString &)), this, SLOT(slotAddHistory(const QString &)));
-    actions.clearLine = new KAction(i18n("&Clear Line"), "locationbar_erase", CTRL+Key_C, 
+    actions.clearLine = new KAction(i18n("&Clear Line"), "locationbar_erase", CTRL+Key_C,
 									this, SLOT(slotClearLine()), actionCollection(), "clear");
+    actions.search = new KAction(i18n("&Start Search"), "key_enter", CTRL+Key_S,
+									this, SLOT(slotStartSearch()), actionCollection(), "search");
 
-  createGUI();	
+  createGUI();
 
-  //--- MainWidget ---  
+  //--- MainWidget ---
   display = new QTextView(this);
-  setCentralWidget(display);	
+  //display->setReadOnly( true );
+  setCentralWidget(display);
 
   SteakDock = new dockwidget();
   SteakDock->setPixmap(BarIcon("ksteak.png"));
-  
+
   connect(SteakDock, SIGNAL(undock()), this, SLOT(slotUndock()));
   connect(SteakDock, SIGNAL(done()), this, SLOT(slotQuit()));
   connect(SteakDock, SIGNAL(configure()), this, SLOT(slotConfigOptions()));
   connect(SteakDock, SIGNAL(translate(const QString &)), this, SLOT(slotTranslateDocked(const QString &)));
 
-  //ga = new KGlobalAccel(); 
-  //ga->insertItem( i18n("global translate"), "global translate", "CTRL+T" ); 
-  //ga->connectItem( "global translate", this, SLOT( slotTranslate() ) ); 
-  //ga->readSettings(); 
-    
+  ga = new KGlobalAccel();
+  ga->insertItem( i18n("KSteak translate"), "KSteak translate", "CTRL+SHIFT+T" );
+  ga->connectItem( "KSteak translate", this, SLOT( slotStartSearch() ) );
+  ga->readSettings();
+
   //reading config-file
   ReadConfig();
   connect( this, SIGNAL(sigDCOPTranslate(const QString &)), this, SLOT(slotTranslateDCOP(const QString &)) );
@@ -90,6 +95,8 @@ KSteak::KSteak()
  *****************************************/
 KSteak::~KSteak()
 {
+	delete display;
+	delete SteakDock;
 }
 
 /*************************************
@@ -101,14 +108,14 @@ void KSteak::slotAddHistory(const QString &s)
   QStringList list = actions.inputLine->items();
   QStringList tlist = s;
 
-  for ( QStringList::Iterator it = list.begin(); ((it != list.end()) & (i < 5)); ++it ) 
-	if ( (s != (*it) ) & (! (*it).isEmpty()) ) 
-	  { 
+  for ( QStringList::Iterator it = list.begin(); ((it != list.end()) & (i < 5)); ++it )
+	if ( (s != (*it) ) & (! (*it).isEmpty()) )
+	{
 		tlist += (*it);
 		i++;
-	  }
-  actions.inputLine->setItems(tlist);
-  slotTranslateUndocked( s );
+	}
+	actions.inputLine->setItems(tlist);
+	slotTranslateUndocked( s );
 }
 
 /***************************************
@@ -120,9 +127,9 @@ void KSteak::slotClearLine()
   QStringList tlist = "";
   QStringList list = actions.inputLine->items();
 
-  for ( QStringList::Iterator it = list.begin(); ((it != list.end()) & (i < 5)); ++it ) 
-	if (! (*it).isEmpty() ) 
-	  { 
+  for ( QStringList::Iterator it = list.begin(); ((it != list.end()) & (i < 5)); ++it )
+	if (! (*it).isEmpty() )
+	  {
 		tlist += (*it);
 		i++;
 	  }
@@ -132,8 +139,13 @@ void KSteak::slotClearLine()
 // --- added by Olaf Hartig (26.Apr.2001)
 void KSteak::slotStartSearch()
 {
-  actions.inputLine->setCurrentItem(0);
-  slotTranslateUndocked( actions.inputLine->currentText() );
+	if (! _fDocked)
+	{
+		actions.inputLine->setCurrentItem( 0 );
+		slotTranslateDCOP( actions.inputLine->currentText() );
+	}
+	else
+		slotTranslateDCOP(kapp->clipboard()->text());
 }
 
 void KSteak::slotToggleEnglish()
@@ -187,7 +199,7 @@ void KSteak::slotShowToolbar()
 void KSteak::slotConfigToolbars()
 {
   KEditToolbar dlg(actionCollection());
-  if (dlg.exec()) 
+  if (dlg.exec())
     {
 	  // recreate our GUI
 	  createGUI();
@@ -200,7 +212,7 @@ void KSteak::slotConfigToolbars()
 void KSteak::slotConfigOptions()
 {
   OptionsDialog *MyDialog = new OptionsDialog(this, "dialog", true);
-  if (MyDialog->exec());
+  if ( MyDialog->exec() );
 }
 
 /****************************************
@@ -225,7 +237,6 @@ void KSteak::applyOptions()
 	}
 }
 
-
 /*****************************************
  save Config (state of Toolbar-Buttons)
  *****************************************/
@@ -264,8 +275,6 @@ void KSteak::ReadConfig(void)
   config = kapp->config();
   // General settings
   config->setGroup("General");
-  if (config->readBoolEntry("docked")) slotDock();
-  else slotUndock();
   // Size
   QSize size = config->readSizeEntry("Size", pSize);
   resize(size);
@@ -288,13 +297,19 @@ void KSteak::ReadConfig(void)
   display->setFont(mFont);
   // ComboBox History
   config->setGroup("Combobox");
-  // list = "";
   list = config->readListEntry("History");
   actions.inputLine->setItems(list);
   // Toolbar options
   config->setGroup("Toolbar");
   actions.showToolbar->setChecked( config->readBoolEntry("visible",true) );
   slotShowToolbar();
+  config->setGroup("General");
+  if (config->readBoolEntry("docked")) slotDock();
+  else slotUndock();
+  
+  delete tempColor;
+  delete pSize;
+  delete pFont;
 }
 
 /*****************************************
@@ -306,7 +321,6 @@ void KSteak::slotQuit(void)
   kapp->quit();
 }
 
-
 /*****************************************
  session management - save settings
  *****************************************/
@@ -315,7 +329,6 @@ void KSteak::saveProperties(KConfig *)
   SaveConfig();
 }
 
-
 /*****************************************
  show dockwidget + hide mainwidget
  *****************************************/
@@ -342,37 +355,46 @@ void KSteak::slotUndock(void)
     }
 }
 
-
 void KSteak::slotTranslateUndocked( const QString & szWord )
 {
-  /* initialize display (font color) */
-  display->setText("<qt text="+textColor.name()+">");
-  /* get translation */
-  _engine.translate( szWord, display);
+	/* get translation */
+	if (display->hasSelectedText())                            // user text-selection?
+	{
+		QString mtext = display->selectedText();    			// save selected text
+		//display->clear();
+		display->setText("<qt text="+textColor.name()+">");    // initialize display (font color)
+		slotAddHistory( mtext );
+	}
+	else	                                                     // translate word from inputline
+	{
+		//display->clear();
+		display->setText("<qt text="+textColor.name()+">");
+		_engine.translate( szWord, display);
+	}
 }
 
-
 void KSteak::slotTranslateDocked( const QString & szWord )
 {
-  /* initialize display (font + colors) */
-  SteakDock->myview->setPaper(QBrush::QBrush(bgColor));
-  SteakDock->mypop->setFont(mFont);
-  SteakDock->myview->setText("<qt text="+textColor.name()+">");
-  /* get translation */
-  _engine.translatePopup( szWord, SteakDock->myview );
+	/* initialize display (font + colors) */
+	//SteakDock->myview->clear();
+	SteakDock->myview->setPaper(QBrush::QBrush(bgColor));
+	SteakDock->mypop->setFont(mFont);
+	SteakDock->myview->setText("<qt text="+textColor.name()+">");
+	/* get translation */
+	_engine.translatePopup( szWord, SteakDock->myview );
 }
 
 void KSteak::slotTranslateDCOP( const QString & szWord )
 {
-   if ( _fDocked )
-     SteakDock->getTranslation( szWord );
-   else
-    {  
-	  setActiveWindow();
-	  this->raise();
-	  this->show();  // this is needed by QTextView (to change context)
-	  slotAddHistory( szWord );
-    }
+	if ( _fDocked )
+		SteakDock->getTranslation( szWord );
+	else
+	{
+		setActiveWindow();
+		this->raise();
+		this->show();  // this is needed by QTextView (to change context)
+		slotAddHistory( szWord );
+	}
 }
 
 void KSteak::translate(const QString & szWord)
