@@ -27,7 +27,10 @@
 #include <kcombobox.h>
 #include <ktoolbar.h>
 #include <qtextview.h>
+//#include <qtextedit.h>
 #include <kaction.h>
+//#include <qclipboard.h>
+#include <kglobalaccel.h>
 
 class KToggleAction;
 
@@ -37,19 +40,21 @@ class KToggleAction;
 
 class KSteak : public KMainWindow, public KSteakIface {
   Q_OBJECT
- public: 
+ public:
   KSteak();
   ~KSteak();
-  
+
   QColor textColor;
   QColor bgColor;
   QFont mFont;
 
+  //QTextView *display;
   QTextView *display;
   QFrame *pMainWidget;
-  
+  KGlobalAccel *ga;
+
   void applyOptions(void);
- 	
+
  public slots:
     virtual bool queryClose() { SaveConfig(); return true; }
 
@@ -79,6 +84,7 @@ class KSteak : public KMainWindow, public KSteakIface {
     KToggleAction * showMenubar;
     /* Actions searchToolbar */
     KAction *clearLine;
+    KAction *search;
     KSelectAction *inputLine;
   } actions;
 
@@ -93,7 +99,7 @@ class KSteak : public KMainWindow, public KSteakIface {
 
   KToolBar *mToolbar;
   KToolBar *pToolbar;
-  KHistoryCombo *SLine;
+ // KHistoryCombo *SLine;
 
   void ReadConfig(void);
   void SaveConfig(void);
@@ -108,7 +114,7 @@ class KSteak : public KMainWindow, public KSteakIface {
   void slotToggleCaseSensitive();
   void slotToggleAND();
   void slotToggleOR();
-  
+
   void slotShowToolbar();
   void slotConfigToolbars();
   void slotConfigKeys();
