@@ -26,17 +26,17 @@
 
 static const char *description =
 I18N_NOOP("KSteak - an english-german dictionary");
-	
+
 int main(int argc, char *argv[])
 {
   KAboutData aboutData( "ksteak", I18N_NOOP("KSteak"),
-						"0.4.0", description, KAboutData::License_GPL,
-						"(c) 2000, 2001 Michael Heidecke");
+						"0.4.3", description, KAboutData::License_GPL,
+						"(c) 2000-2002 Michael Heidecke");
   aboutData.addAuthor("Michael Heidecke", 0, "heidecke@web.de");
   aboutData.addAuthor("Olaf Hartig", 0, "olebowle@gmx.de");
-  
+
   KCmdLineArgs::init( argc, argv, &aboutData );
-  
+
   KApplication a;
 
   KSteak *ksteak = new KSteak();
@@ -46,7 +46,7 @@ int main(int argc, char *argv[])
 
   DCOPClient * pClient = a.dcopClient();
   pClient->attach();
-  pClient->registerAs( aboutData.appName() );
-  
+  pClient->registerAs( "ksteak", false );
+
   return a.exec();
 }
